@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Config.pm 3673 2006-07-25 19:18:34Z sysjkf $
+#   $Id: Config.pm 3766 2006-11-05 21:46:28Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ no  strict 'subs'; # Allow bare words for parameter %'s
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3673 $, 10;
+$VERSION = substr q$Revision: 3766 $, 10;
 
 #1 exception to general rule of forming replies to Config::Value()
 #is %Config::ScannerCmds
@@ -665,7 +665,8 @@ sub QuickPeek {
     # Connect and bind
     $connection = Net::LDAP->new($ldapserver, onerror=>'warn') or
       print STDERR "Making LDAP connection error: $@\n";
-    $binding = $connection->bind($ldapbase, anonymous=>1);
+    # Change for JPK $binding = $connection->bind($ldapbase, anonymous=>1);
+    $binding = $connection->bind();
     $binding->code and
       print STDERR "LDAP binding error: $@\n";
 
@@ -1782,7 +1783,7 @@ sub ReadData {
       #print STDERR "Unrecognised keyword \"" . ItoE($leftover) .
       #             "\" at line " . $LineNos{$leftover} . "\n";
     }
-    MailScanner::Log::WarnLog("Aborting due to syntax errors in %s.",
+    MailScanner::Log::WarnLog("Warning: syntax errors in %s.",
                              $filename);
   }
 }
