@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ConfigDefs.pl 3684 2006-08-03 21:49:18Z sysjkf $
+#   $Id: ConfigDefs.pl 3761 2006-10-30 22:28:25Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ clamavmaxfilesize		= clamavmodulemaximumfilesize
 clamavmaxratio			= clamavmodulemaximumcompressionratio
 clamwatchfiles			= monitorsforclamavupdates
 cleanheader			= cleanheadervalue
-contentprependsubject		= contentmodifysubject
+contentmodifysubject		= contentmodifysubject
 contentsubjecttext		= contentsubjecttext
 criticalqueuesize		= maxnormalqueuesize
 dangerscan			= dangerouscontentscanning
@@ -83,7 +83,7 @@ deletedvirusmessage		= deletedvirusmessagereport
 deliverdisinfected		= deliverdisinfectedfiles
 deliversilent			= stilldeliversilentviruses
 dirtyheader			= infectedheadervalue
-disarmprependsubject		= disarmedmodifysubject
+disarmmodifysubject		= disarmedmodifysubject
 disarmsubjecttext		= disarmedsubjecttext
 disinfectedheader		= disinfectedheadervalue
 disinfectedreporttext		= disinfectedreport
@@ -99,8 +99,8 @@ hideworkdirinnotice		= hideincomingworkdirinnotices
 highrbls                        = spamliststoreachhighscore
 highscorespamactions		= highscoringspamactions
 highscoremcpactions		= highscoringmcpactions
-highmcpprependsubject		= highscoringmcpmodifysubject
-highspamprependsubject		= highscoringspammodifysubject
+highmcpmodifysubject		= highscoringmcpmodifysubject
+highspammodifysubject		= highscoringspammodifysubject
 highmcpsubjecttext		= highscoringmcpsubjecttext
 highspamsubjecttext		= highscoringspamsubjecttext
 htmltotext			= converthtmltotext
@@ -132,7 +132,7 @@ maxunscannedmessages		= maxunscannedmessagesperscan
 maxzipdepth			= maximumarchivedepth
 minattachmentsize		= minimumattachmentsize
 minstars			= minimumstarsifonspamlist
-nameprependsubject		= filenamemodifysubject
+namemodifysubject		= filenamemodifysubject
 namesubjecttext			= filenamesubjecttext
 noisyviruses			= nonforgingviruses
 normalrbls                      = spamliststobespam
@@ -174,10 +174,10 @@ sophoside			= sophosidedir
 sophoslib			= sophoslibdir
 spamblacklist			= isdefinitelyspam
 spamdetail			= detailedspamreport
-mcpprependsubject		= mcpmodifysubject
-sizeprependsubject		= sizemodifysubject
+mcpmodifysubject		= mcpmodifysubject
+sizemodifysubject		= sizemodifysubject
 sizesubjecttext			= sizesubjecttext
-spamprependsubject		= spammodifysubject
+spammodifysubject		= spammodifysubject
 spamscorenotstars		= spamscorenumberinsteadofstars
 spamstars			= spamscore
 spamstarscharacter		= spamscorecharacter
@@ -200,7 +200,7 @@ unscannedheader			= unscannedheadervalue
 usedefaultswithmanyrecips       = usedefaultruleswithmultiplerecipients
 tagphishingsubject		= phishingmodifysubject
 #virusbeforespammcp		= virusscanningbeforespamormcp
-virusprependsubject		= virusmodifysubject
+virusmodifysubject		= virusmodifysubject
 virusscan			= virusscanning
 warnsenders			= notifysenders
 warnvirussenders		= notifysendersofviruses
@@ -277,7 +277,7 @@ MaxDirtyMessages		30
 MaxGSSize			20000
 MaxGSTimeouts			10
 MaxSpamAssassinTimeouts		10
-MaxSpamAssassinSize		30000
+MaxSpamCheckSize		150000
 QueueScanInterval		6
 RBLTimeoutLen			10
 RestartEvery			14400
@@ -286,7 +286,6 @@ SpamListTimeout			10
 SpamAssassinTimeout		75
 VirusScannerTimeout		300
 MCPMaxSpamAssassinTimeouts	20
-MCPMaxSpamAssassinSize		100000
 MCPSpamAssassinTimeout		10
 TNEFTimeout			120
 UnrarTimeout			50
@@ -313,6 +312,7 @@ LDAPsite
 LockType
 LogFacility		mail
 MailScannerVersionNumber	1.0.0
+MaxSpamAssassinSize		30000
 MinimumCodeStatus	supported
 MTA			sendmail
 QuarantineUser
@@ -332,6 +332,7 @@ SpamAssassinLocalStateDir
 SpamAssassinDefaultRulesDir	
 SpamAssassinInstallPrefix	
 SpamStarsCharacter	s
+MCPMaxSpamAssassinSize		100000
 MCPSpamAssassinUserStateDir
 MCPSpamAssassinLocalRulesDir	/etc/MailScanner/mcp
 MCPSpamAssassinDefaultRulesDir	/etc/MailScanner/mcp
@@ -355,19 +356,19 @@ blacklistedishigh	0	no	0	yes	1
 bouncemcpasattachment	0	no	0	yes	1
 bouncespamasattachment	0	no	0	yes	1
 CheckSAIfOnSpamList	1	no	0	yes	1
-ContentPrependSubject	1	no	0	yes	1
+ContentModifySubject	start	no	0	yes	1	start	start	end	end
 DeliverDisinfected	0	no	0	yes	1
 DeliverSilent		0	no	0	yes	1
 deliverunparsabletnef	0	no	0	yes	1
 deliverymethod		batch	batch	batch	queue	queue
-DisarmPrependSubject	1	no	0	yes	1
+DisarmModifySubject	start	no	0	yes	1	start	start	end	end
 EnableSpamBounce	0	no	0	yes	1
 findarchivesbycontent	1	no	0	yes	1
 gsscanner		0	no	0	yes	1
 HideWorkDir		1	no	0	yes	1
 HideWorkDirInNotice	0	no	0	yes	1
-HighMCPPrependSubject	1	no	0	yes	1
-HighSpamPrependSubject	1	no	0	yes	1
+HighMCPModifySubject	start	no	0	yes	1	start	start	end	end
+HighSpamModifySubject	start	no	0	yes	1	start	start	end	end
 IncludeSpamHeader	0	no	0	yes	1
 IncludeMCPHeader	0	no	0	yes	1
 KeepSpamArchiveClean	0	no	0	yes	1
@@ -380,19 +381,19 @@ LogPermittedFilenames	0	no	0	yes	1
 LogPermittedFiletypes	0	no	0	yes	1
 LookForUU		0	no	0	yes	1
 MultipleHeaders		append	append	append	replace	replace	add	add
-NamePrependSubject	1	no	0	yes	1
+NameModifySubject	start	no	0	yes	1	start	start	end	end
 NoticeFullHeaders	1	no	0	yes	1
-scannedmodifysubject	0	no	0	start	start	end	end
+ScannedModifySubject	0	no	0	yes	1	start	start	end	end
 SendNotices		1	no	0	yes	1
 SignAlreadyScanned	0	no	0	yes	1
 SignCleanMessages	1	no	0	yes	1
 SignUnscannedMessages	1	no	0	yes	1
-SizePrependSubject	1	no	0	yes	1
+SizeModifySubject	start	no	0	yes	1	start	start	end	end
 SpamBlacklist		0	no	0	yes	1
 SpamDetail		1	no	0	yes	1
 SpamChecks		1	no	0	yes	1
-MCPPrependSubject	1	no	0	yes	1
-SpamPrependSubject	1	no	0	yes	1
+MCPModifySubject	start	no	0	yes	1	start	start	end	end
+SpamModifySubject	start	no	0	yes	1	start	start	end	end
 SpamScoreNotStars	0	no	0	yes	1
 SpamWhitelist		0	no	0	yes	1
 StripDangerousTags	0	no	0	yes	1
@@ -403,7 +404,7 @@ MCPDetail		1	no	0	yes	1
 MCPListSAScores		0	no	0	yes	1
 MCPWhitelist		0	no	0	yes	1
 UseSACache		1	no	0	yes	1
-VirusPrependSubject	1	no	0	yes	1
+VirusModifySubject	start	no	0	yes	1	start	start	end	end
 warningisattachment	1	no	0	yes	1
 WarnSenders		1	no	0	yes	1
 WarnVirusSenders	0	no	0	yes	1
@@ -531,7 +532,7 @@ ReplaceTNEF		2	no	0	add	1	replace	2
 ScanMail		1	no	0	yes	1
 SpamStars		1	no	0	yes	1
 StrictPhishing          1       no      0       yes     1
-TagPhishingSubject	0	no	0 	yes	1
+TagPhishingSubject	0	no	0 	yes	1	start	start	end	end
 MCPUseSpamAssassin	1	no	0	yes	1
 UseSpamAssassin		1	no	0	yes	1
 VirusScan		1	no	0	yes	1
