@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Exim.pm,v 1.24.2.43 2006/01/16 10:53:35 jkf Exp $
+#   $Id: Exim.pm 3638 2006-06-17 20:28:07Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ use IO::Pipe;
 use Carp;
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.24.2.43 $, 10;
+$VERSION = substr q$Revision: 3638 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process
 # a message that is piped to it. Still need to add the envelope sender
@@ -251,7 +251,7 @@ sub ReadQf {
 
   my %metadata;
   my($InHeader, $InSubject, $InDel, @headers, $msginfo, $from, @to, $subject);
-  my($ip, $sender, @acl, $line);
+  my($ip, $sender, @acl, @aclc, @aclm, $line, $acltype);
 
   # Seek to the start of the file in case anyone read the file
   # between me opening it and locking it.
@@ -287,13 +287,24 @@ sub ReadQf {
     #$line eq "" and $metadata{"dv_$1"} = 1, next;
     #$metadata{"dv_$1"} = $line;
     #$metadata{dashvars}{$1} = 1;
-    if($1 eq "acl") {
+    # ACLs can be -acl or -aclc or -aclm.
+    $acltype = $1;
+    if($acltype =~ /^acl[cm]?$/) {
       # we need to handle acl vars differently
       if($line =~ /^(\d+) (\d+)$/) {
         my $buf;
         my $pos = $1;
         my $len = $2;
-        $acl[$pos]=[];
+        if ($acltype eq "acl") {
+          $acl[$pos]->[0] = [];
+        } elsif ($acltype eq "aclc") {
+          $aclc[$pos]->[0] = [];
+        } elsif ($acltype eq "aclm") {
+          $aclm[$pos]->[0] = [];
+        } else {
+          # invalid format
+          last;
+        }
         (read($RQf, $buf, $len + 1)==$len+1) or last;
         if($buf =~ /\n$/) {
           chomp $buf;
@@ -301,7 +312,16 @@ sub ReadQf {
           # invalid format
           last;
         }
-        $acl[$pos]->[0] = $buf;
+        if ($acltype eq "acl") {
+          $acl[$pos]->[0] = $buf;
+        } elsif ($acltype eq "aclc") {
+          $aclc[$pos]->[0] = $buf;
+        } elsif ($acltype eq "aclm") {
+          $aclm[$pos]->[0] = $buf;
+        } else {
+          # invalid format
+          last;
+        }
       } else {
         # this is a weird format, and we're not sure how to handle it
         last;
@@ -315,6 +335,8 @@ sub ReadQf {
     next;
   }
   $metadata{aclvars} = \@acl;
+  $metadata{aclcvars} = \@aclc;
+  $metadata{aclmvars} = \@aclm;
 
   # If it was an invalid queue file, log a warning and tell caller
   unless (defined $line) {
@@ -465,13 +487,13 @@ sub ReadQf {
       # We are expecting a continuation line...
       $InHeader -= (length($line));
       if ($InHeader < 0) {
-	MailScanner::Log::InfoLog("Header ($line) too long (wanted $InHeader)".
-		     "-- using it anyway!!");
+	MailScanner::Log::NoticeLog("Header ($line) too long (wanted " .
+                     "$InHeader) -- using it anyway!!");
 	$InHeader = 0;
       }
       $line =~ /^[\t ]/
-	or MailScanner::Log::InfoLog("Header continuation ($line) doesn't begin".
-			" with LWSP -- using it anyway!!");
+	or MailScanner::Log::NoticeLog("Header continuation ($line) doesn't" .
+                        " begin with LWSP -- using it anyway!!");
 
       # Push line onto simple @headers array unless it's one
       # that Exim's flagged as deleted...
@@ -564,7 +586,18 @@ sub ReadQf {
   # much better than the MIME-tools default handling.
   MIME::WordDecoder->default->handler('*' => \&MailScanner::Message::WordDecoderKeep7Bit);
   # Decode the ISO encoded Subject line
-  $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
+  my $TmpSubject = MIME::WordDecoder::unmime($message->{subject});
+  if ($TmpSubject ne $message->{subject}) {
+    # The unmime function dealt with an encoded subject, as it did
+    # something. Allow up to 10 trailing spaces so that SweepContent
+    # is more kind to us and doesn't go and replace the whole subject,
+    # thinking that it is malicious. Total replacement and hence
+    # destruction of unicode subjects is rather harsh when we are just
+    # talking about a few spaces.
+    $TmpSubject =~ s/ {1,10}$//;
+    $message->{subject} = $TmpSubject;
+  }
+  #old $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
 
   # I'd prefer that $message->{headers} not exist;
   # it's an incitement to do bad things that defeat
@@ -1059,12 +1092,25 @@ sub CreateQf {
 
   # ACLs patch starts here
   # Add the separate ACL Vars
-  my @acl = @{$metadata->{aclvars}};
-  for($i=0; $i<=$#acl; $i++) {
+  my @acl  = @{$metadata->{aclvars}};
+  my @aclc = @{$metadata->{aclcvars}};
+  my @aclm = @{$metadata->{aclmvars}};
+  my $greatestacl = $#acl;
+  $greatestacl    = $#aclc if $#aclc > $greatestacl;
+  $greatestacl    = $#aclm if $#aclm > $greatestacl;
+  for($i=0; $i<=$greatestacl; $i++) {
     if($acl[$i]) {
       $Qfile .= "-acl " . $i . " " . length($acl[$i]->[0]) . "\n";
       $Qfile .= $acl[$i]->[0] . "\n";
     }
+    if($aclc[$i]) {
+      $Qfile .= "-aclc " . $i . " " . length($aclc[$i]->[0]) . "\n";
+      $Qfile .= $aclc[$i]->[0] . "\n";
+    }
+    if($aclm[$i]) {
+      $Qfile .= "-aclm " . $i . " " . length($aclm[$i]->[0]) . "\n";
+      $Qfile .= $aclm[$i]->[0] . "\n";
+    }
   }
 
   # Add non-recipients
@@ -1482,7 +1528,7 @@ sub CreateBatch {
   } while $batchempty;		# Keep trying until we get something
 
   # Log the number of invalid messages found
-  MailScanner::Log::InfoLog("New Batch: Found invalid queue files: %s",
+  MailScanner::Log::NoticeLog("New Batch: Found invalid queue files: %s",
                             $invalidfiles)
     if $invalidfiles;
   # Log the size of the queue if it is more than 1 batch
