@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: EximDiskStore.pm 3266 2005-12-20 18:19:35Z jkf $
+#   $Id: EximDiskStore.pm 3743 2006-10-09 15:42:09Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ use MailScanner::Config;
 use vars qw($VERSION @DeletesPending);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3266 $, 10;
+$VERSION = substr q$Revision: 3743 $, 10;
 
 # List of pending delete operations so we can clear up properly when killed
 @DeletesPending = ();
@@ -59,7 +59,7 @@ $VERSION = substr q$Revision: 3266 $, 10;
 #use vars qw($VERSION);
 #
 #### The package version, both in 1.23 style *and* usable by MakeMaker:
-#$VERSION = substr q$Revision: 3266 $, 10;
+#$VERSION = substr q$Revision: 3743 $, 10;
 
 # Attributes are
 #
@@ -335,6 +335,14 @@ sub ReadBody {
   my $line = <$dh>;
   # FIXME: check that id is correct here
 
+  my @configwords = split(" ", $max);
+  $max = $configwords[0];
+  $max =~ s/_//g;
+  $max =~ s/k$/000/ig;
+  $max =~ s/m$/000000/ig;
+  $max =~ s/g$/000000000/ig;
+  #print STDERR "Words are " . join(',',@configwords) . "\n";
+
   # Only use $max if it was set non-zero
   if ($max) {
     my $size = 0;
@@ -342,6 +350,13 @@ sub ReadBody {
       push @{$body}, $line;
       $size += length($line);
     }
+    # Continue copying until we hit a blank line, gives SA a complete
+    # encoded attachment
+    #while(defined $line) {
+    #  $line = <$dh>;
+    #  last if $line =~ /^\s+$/;
+    #  push @{$body}, $line if defined $line;
+    #}
   } else {
     while(<$dh>) {
       # End of line characters are already there, so don't add them
