@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: MessageBatch.pm 3684 2006-08-03 21:49:18Z sysjkf $
+#   $Id: MessageBatch.pm 3780 2006-11-29 13:43:10Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ use Time::HiRes qw ( time );
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3684 $, 10;
+$VERSION = substr q$Revision: 3780 $, 10;
 
 my $maxcleanbytes    = 0;
 my $maxcleanmessages = 0;
@@ -251,7 +251,7 @@ sub SpamChecks {
   MailScanner::SA::CheckForCacheExpire();
 
   while(($id, $message) = each %{$this->{messages}}) {
-    next unless $message->{scanmail};
+    next if $message->{scanmail} =~ /^[0\s]+$/;
     next if $message->{deleted};
     next unless MailScanner::Config::Value('spamchecks', $message) =~ /1/;
  
@@ -280,9 +280,10 @@ sub HandleSpam {
 
   while(($id, $message) = each %{$this->{messages}}) {
     # Skip deleted and non-spam messages
+    #print STDERR "Deleted = " . $message->{deleted} . ", isspam = " . $message->{isspam} . ", scanmail = " . $message->{scanmail} . ", spamwhitelisted = " . $message->{spamwhitelisted} . "\n";
     next if  $message->{deleted} ||
             !$message->{isspam}  ||
-            !$message->{scanmail}||
+             $message->{scanmail} =~ /^[0\s]+$/ ||
              $message->{spamwhitelisted};
 
     #print STDERR "Spam checks for $id\n";
@@ -304,7 +305,7 @@ sub HandleHam {
   while(($id, $message) = each %{$this->{messages}}) {
     # Skip deleted and non-spam messages
     next if $message->{deleted} ||
-           !$message->{scanmail}||
+            $message->{scanmail} =~ /^[0\s]+$/ ||
             $message->{isspam};
 
     #print STDERR "Ham checks for $id\n";
@@ -345,7 +346,7 @@ sub MCPChecks {
 
   while(($id, $message) = each %{$this->{messages}}) {
     next if $message->{deleted};
-    next unless $message->{scanmail};
+    next if $message->{scanmail} =~ /^[0\s]+$/;
     next unless MailScanner::Config::Value('mcpchecks', $message);
  
     #print STDERR "Spam checks for $id\n";
@@ -376,7 +377,7 @@ sub HandleMCP {
     # Skip deleted and non-spam messages
     next if  $message->{deleted} ||
             !$message->{ismcp}   ||
-            !$message->{scanmail}||
+             $message->{scanmail} =~ /^[0\s]+$/ ||
              $message->{mcpwhitelisted};
 
     #print STDERR "Spam checks for $id\n";
@@ -398,7 +399,7 @@ sub HandleNonMCP {
   while(($id, $message) = each %{$this->{messages}}) {
     # Skip deleted and non-spam messages
     next if $message->{deleted} ||
-           !$message->{scanmail}||
+            $message->{scanmail} =~ /^[0\s]+$/ ||
             $message->{ismcp};
 
     #print STDERR "Ham checks for $id\n";
@@ -421,7 +422,7 @@ sub DeliverUnscanned {
     next if $message->{deleted} || $message->{dontdeliver};
 
     # This is for mail we don't want to touch at all
-    if (!$message->{scanmail}) {
+    if ($message->{scanmail} =~ /^[0\s]+$/) {
       $OutQ = MailScanner::Config::Value('outqueuedir', $message);
       $message->DeliverUntouched($OutQ);
       $message->{deleted} = 1; # This marks it for purging from disk
