@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Postfix.pm 3667 2006-07-23 11:53:50Z sysjkf $
+#   $Id: Postfix.pm 3727 2006-09-24 11:18:34Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3667 $, 10;
+$VERSION = substr q$Revision: 3727 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -906,7 +906,11 @@ sub new {
     for ($linenum=0; $linenum<@{$message->{metadata}}; $linenum++) {
       # Looking for "recipient" lines
       # Should allow 'O' here as well
-      next unless $message->{metadata}[$linenum] =~ /^[RO]/;
+      # JKF 30/08/2006 next unless $message->{metadata}[$linenum] =~ /^[RO]/;
+      # Thanks to Holger Gebhard for this.
+      #BUGGY: next unless $message->{metadata}[$linenum] =~ /^[ARO].+@(?:\w|-|\.)+\.\w{2,})/;
+      #next unless $message->{metadata}[$linenum] =~ /^[ARO]/;
+      next unless $message->{metadata}[$linenum] =~ /^[ARO].+@(?:\w|-|\.)+\.\w{2,}/;
       # Have found the right line
       #print STDERR "Deleting recip " . $message->{metadata}[$linenum] . "\n";
       splice(@{$message->{metadata}}, $linenum, 1);
