@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Sendmail.pm 3687 2006-08-04 15:13:01Z sysjkf $
+#   $Id: Sendmail.pm 3729 2006-09-24 15:47:39Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3687 $, 10;
+$VERSION = substr q$Revision: 3729 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -690,14 +690,23 @@ my($sed) = "/bin/sed";
 
   sub KickMessage {
     my(@ids) = @_;
-    my $idlist = '';
+    my $args = '';
 
-    my $outqdir = MailScanner::Config::Value('outqueuedir');
-    $idlist = " -OQueueDirectory=$outqdir " if $outqdir;
-    $idlist .= join(' -qI', @ids);
-    $idlist .= ' &' if MailScanner::Config::Value('deliverinbackground');
-    #print STDERR "About to do \"Sendmail2 -qI$idlist\"\n";
-    system(MailScanner::Config::Value('sendmail2') . ' -qI' . $idlist);
+    # Null addresses may cause a complete queue run!
+    my($ids, $id);
+    $ids = '';
+    foreach $id (@ids) {
+      $ids .= " -qI$id" if $id;
+    }
+
+    if ($ids) {
+      my $outqdir = MailScanner::Config::Value('outqueuedir');
+      $args = " -OQueueDirectory=$outqdir " if $outqdir;
+      $args .= $ids;
+      $args .= ' &' if MailScanner::Config::Value('deliverinbackground');
+      #print STDERR "About to do \"" . MailScanner::Config::Value('sendmail2') . $args . "\"\n";
+      system(MailScanner::Config::Value('sendmail2') . $args);
+    }
   }
 
   sub CreateQf {
